@@ -10,9 +10,9 @@ function(geno.files,index,surv.data)
 		}
 		else{
 			curr.ind = 0
-			for(j in 2:i){
-				curr.ind = curr.ind+nrow(get(geno.files[j-1]))
-}
+			for(j in 2:i)
+			      curr.ind = curr.ind+nrow(get(geno.files[j-1]))
+
 			surv = c(surv,surv.data[[1]][(curr.ind+1):(curr.ind+nrow(get(geno.files[i])))])
 			censor = c(censor,surv.data[[2]][(curr.ind+1):(curr.ind+nrow(get(geno.files[i])))])
 		}		
