@@ -1,5 +1,5 @@
 main.process <-
-function(common.gene, geno.files, surv.data,batchID,method = "none")
+function(common.gene, geno.files, surv.data,method = "none", time.dep)
 {
 	curr_set = 1:length(geno.files)
 	norm.set = c("combat","zscore1", "zscore2")
@@ -21,15 +21,16 @@ function(common.gene, geno.files, surv.data,batchID,method = "none")
 				"zscore1"=(col = "blue"),
 				"zscore2"=(col = "green")
 			)
+
 			if (normalization == "zscore1" || normalization == "combat")
-				splitMerged.auc.plot (geno.files, lst, x, y,col, method)
+				splitMerged.auc.plot (geno.files, lst, x, y,col, method, time.dep)
 			else
-				splitZscore2.auc.plot (common.gene,geno.files,surv.data, lst, x, y,col, method)
+				splitZscore2.auc.plot (common.gene,geno.files,surv.data, lst, x, y,col, method, time.dep)
 		}
-		abline(0.5,0,col = "red")
-		legend(50,0.2,legend = c("ComBat","Zscore1","Zscore2"), text.col = color.set, bty = "n", pt.cex = .5)	
+		if (time.dep) abline(0.5,0,col = "red") 
+		if (time.dep) legend(50,0.2,legend = c("ComBat","Zscore1","Zscore2"), text.col = color.set, bty = "n", pt.cex = .5) 
 	}
 
-	title(main = "Time-dependent AUC based on predicted time\nIndependent validation",outer = TRUE, cex.main=1.5)
+	if (time.dep) title(main = "Time-dependent AUC based on predicted time\nIndependent validation",outer = TRUE, cex.main=1.5) 
 }
 
